@@ -20,23 +20,23 @@ class Parser:
 
     def __init__(self, nominator: str, denominator: str):
         func = Word(alphas)
-        unit_type = Word(alphas + '_').setParseAction(UnitType)
+        unit_type = Word(alphas + "_").setParseAction(UnitType)
         agg_type = Word(alphas).setParseAction(AggType)
-        goal = Word(alphas + '_' + nums).setParseAction(Goal)
+        goal = Word(alphas + "_" + nums).setParseAction(Goal)
         number = Word(nums).setParseAction(Number)
-        dimension = Word(alphas + '_').setParseAction(Dimension)
-        dimension_value = Word(alphanums + '_' + '-' + '.').setParseAction(DimensionValue)
+        dimension = Word(alphas + "_").setParseAction(Dimension)
+        dimension_value = Word(alphanums + "_" + "-" + "." + "%").setParseAction(DimensionValue)
 
-        ep_goal = (func + '(' + unit_type + '.' + agg_type + '.' + goal + ')').setParseAction(EpGoal)
+        ep_goal = (func + "(" + unit_type + "." + agg_type + "." + goal + ")").setParseAction(EpGoal)
         ep_goal_with_dimension = (
-            func + '(' + unit_type + '.' + agg_type + '.' + goal + '(' + dimension + '=' + dimension_value + ')' + ')'
+            func + "(" + unit_type + "." + agg_type + "." + goal + "(" + dimension + "=" + dimension_value + ")" + ")"
         ).setParseAction(EpGoal)
         operand = number | ep_goal | ep_goal_with_dimension
 
-        multop = oneOf('*')
-        divop = oneOf('/')
-        plusop = oneOf('+')
-        subop = oneOf('-')
+        multop = oneOf("*")
+        divop = oneOf("/")
+        plusop = oneOf("+")
+        subop = oneOf("-")
 
         expr = infixNotation(
             operand,
@@ -86,24 +86,24 @@ class Parser:
             numpy array of shape (variants, metrics) where metrics are in order of
             (count, sum_value, sum_sqr_value)
         """
-        value_variants, value = self._nominator_expr.evaluate_by_unit(goals, 'sum_value')
+        value_variants, value = self._nominator_expr.evaluate_by_unit(goals, "sum_value")
         value_df = (
             pd.DataFrame(
                 {
-                    'exp_variant_id': value_variants,  # go through variants
-                    'sum_value': value,
-                    'sum_sqr_value': value * value,
+                    "exp_variant_id": value_variants,  # go through variants
+                    "sum_value": value,
+                    "sum_sqr_value": value * value,
                 }
             )
-            .groupby('exp_variant_id')
+            .groupby("exp_variant_id")
             .sum()
         )
 
-        count_variants, count = self._denominator_expr.evaluate_by_unit(goals, 'count')
-        count_df = pd.DataFrame({'exp_variant_id': count_variants, 'count': count}).groupby('exp_variant_id').sum()
+        count_variants, count = self._denominator_expr.evaluate_by_unit(goals, "count")
+        count_df = pd.DataFrame({"exp_variant_id": count_variants, "count": count}).groupby("exp_variant_id").sum()
 
         df = value_df.join(count_df)
-        return df['count'], df['sum_value'], df['sum_sqr_value']
+        return df["count"], df["sum_value"], df["sum_sqr_value"]
 
     def get_goals(self) -> Set:
         """
@@ -130,8 +130,8 @@ class UnitType:
 
 class AggType:
     def __init__(self, t):
-        if t[0] not in ['unit', 'global']:
-            raise ParseException(f'Only `unit` and `global` aggregation types are supported but `{t[0]}` received.')
+        if t[0] not in ["unit", "global"]:
+            raise ParseException(f"Only `unit` and `global` aggregation types are supported but `{t[0]}` received.")
         self.agg_type = t[0]
 
     def __str__(self):
@@ -175,7 +175,7 @@ class Number:
         self.value = float(t[0])
 
     def __str__(self):
-        return f'{self.value}'
+        return f"{self.value}"
 
     def evaluate_agg(self, goals):
         return self.value
@@ -203,27 +203,27 @@ class EpGoal:
     """
 
     def __init__(self, t):
-        if t[0] not in ['value', 'count', 'unique']:
-            raise ParseException(f'Only `value`, `count`, `unique` functions are supported but `{t[0]}` received.')
-        if t[0] == 'value':
-            self.column = 'sum_value' if t[0] == 'value' else 'count'
-            self.column_sqr = 'sum_sqr_value' if t[0] == 'value' else 'sum_sqr_count'
-        if t[0] == 'count':
-            self.column = 'count'
-            self.column_sqr = 'sum_sqr_count'
-        if t[0] == 'unique':
-            self.column = 'count_unique'
-            self.column_sqr = 'count_unique'
+        if t[0] not in ["value", "count", "unique"]:
+            raise ParseException(f"Only `value`, `count`, `unique` functions are supported but `{t[0]}` received.")
+        if t[0] == "value":
+            self.column = "sum_value" if t[0] == "value" else "count"
+            self.column_sqr = "sum_sqr_value" if t[0] == "value" else "sum_sqr_count"
+        if t[0] == "count":
+            self.column = "count"
+            self.column_sqr = "sum_sqr_count"
+        if t[0] == "unique":
+            self.column = "count_unique"
+            self.column_sqr = "count_unique"
 
         self.unit_type = t[2].unit_type
         self.agg_type = t[4].agg_type
         self.goal = t[6].goal
-        self.dimension = t[8].dimension if len(t) > 8 else ''
-        self.dimension_value = t[10].dimension_value if len(t) > 8 else ''
+        self.dimension = t[8].dimension if len(t) > 8 else ""
+        self.dimension_value = t[10].dimension_value if len(t) > 8 else ""
 
     def _to_string(self):
-        dimension = f'[{self.dimension}={self.dimension_value}]' if self.dimension != '' else ''
-        return f'{self.unit_type}.{self.agg_type}.{self.goal}{dimension}'
+        dimension = f"[{self.dimension}={self.dimension_value}]" if self.dimension != "" else ""
+        return f"{self.unit_type}.{self.agg_type}.{self.goal}{dimension}"
 
     def __str__(self):
         return self._to_string()
@@ -241,23 +241,23 @@ class EpGoal:
 
     def evaluate_by_unit(self, goals, key):
         g = goals[
-            (goals['unit_type'] == self.unit_type)
-            & (goals['agg_type'] == self.agg_type)
-            & (goals['dimension'] == self.dimension)
-            & (goals['dimension_value'] == self.dimension_value)
+            (goals["unit_type"] == self.unit_type)
+            & (goals["agg_type"] == self.agg_type)
+            & (goals["dimension"] == self.dimension)
+            & (goals["dimension_value"] == self.dimension_value)
         ]
-        return g['exp_variant_id'], g.xs(key=key, level=1, axis=1)[self.goal]
+        return g["exp_variant_id"], g.xs(key=key, level=1, axis=1)[self.goal]
 
     def evaluate_sqr(self, goals):
         return self._evaluate_agg(goals, self.column_sqr)
 
     def _evaluate_agg(self, goals, column):
         return goals[
-            (goals['unit_type'] == self.unit_type)
-            & (goals['agg_type'] == self.agg_type)
-            & (goals['goal'] == self.goal)
-            & (goals['dimension'] == self.dimension)
-            & (goals['dimension_value'] == self.dimension_value)
+            (goals["unit_type"] == self.unit_type)
+            & (goals["agg_type"] == self.agg_type)
+            & (goals["goal"] == self.goal)
+            & (goals["dimension"] == self.dimension)
+            & (goals["dimension_value"] == self.dimension_value)
         ][column].values
 
     def get_goals_str(self) -> Set[str]:
@@ -267,7 +267,7 @@ class EpGoal:
         return {self}
 
     def is_dimensional(self):
-        return self.dimension != '' and self.dimension_value != ''
+        return self.dimension != "" and self.dimension_value != ""
 
     __repr__ = __str__
 
@@ -300,15 +300,15 @@ class BinOp:
         return set().union(*map(lambda o: o.get_goals(), self.args))
 
     def __str__(self):
-        sep = f' {self.symbol()} '
-        return '(' + sep.join(map(str, self.args)) + ')'
+        sep = f" {self.symbol()} "
+        return "(" + sep.join(map(str, self.args)) + ")"
 
     __repr__ = __str__
 
 
 class PlusBinOp(BinOp):
     def symbol(self):
-        return '+'
+        return "+"
 
     def evaluate_agg(self, goals):
         return self.args[0].evaluate_agg(goals) + self.args[1].evaluate_agg(goals)
@@ -322,7 +322,7 @@ class PlusBinOp(BinOp):
 
 class MultBinOp(BinOp):
     def symbol(self):
-        return '*'
+        return "*"
 
     def evaluate_agg(self, goals):
         return self.args[0].evaluate_agg(goals) * self.args[1].evaluate_agg(goals)
@@ -336,7 +336,7 @@ class MultBinOp(BinOp):
 
 class DivBinOp(BinOp):
     def symbol(self):
-        return '/'
+        return "/"
 
     def evaluate_agg(self, goals):
         return self.args[0].evaluate_agg(goals) / self.args[1].evaluate_agg(goals)
@@ -350,7 +350,7 @@ class DivBinOp(BinOp):
 
 class SubBinOp(BinOp):
     def symbol(self):
-        return '-'
+        return "-"
 
     def evaluate_agg(self, goals):
         return self.args[0].evaluate_agg(goals) - self.args[1].evaluate_agg(goals)
